@@ -5,6 +5,7 @@ Contains the worker classes/functions executed on the server side.
 """
 import logging
 import os
+import tempfile
 import jedi
 
 
@@ -43,8 +44,8 @@ def calltips(request_data):
                    sig.bracket_start, column)
         # todo: add support for multiple signatures, for that we need a custom
         # widget for showing calltips.
-        return True, results
-    return False, []
+        return results
+    return []
 
 
 def goto_assignments(request_data):
@@ -66,7 +67,7 @@ def goto_assignments(request_data):
         ret_val = [(d.module_path, d.line - 1 if d.line else None,
                     d.column, d.full_name)
                    for d in definitions]
-        return True, ret_val
+        return ret_val
 
 
 _old_definitions = {}
@@ -135,7 +136,15 @@ class Definition(object):
 def _extract_def(d):
     d_line, d_column = d.start_pos
     # use full name for import type
-    definition = Definition(d.name, icon_from_typename(d.name, d.type),
+    if d.type == 'function':
+        try:
+            params = [p.name for p in d.params]
+            name = d.name + '(' + ', '.join(params) + ')'
+        except AttributeError:
+            name = d.name
+    else:
+        name = d.name
+    definition = Definition(name, icon_from_typename(d.name, d.type),
                             d_line - 1, d_column, d.full_name)
     # check for methods in class or nested methods/classes
     if d.type == "class" or d.type == 'function':
@@ -162,13 +171,10 @@ def defined_names(request_data):
     for d in toplvl_definitions:
         definition = _extract_def(d)
         if d.type != 'import':
-            # ignore imports
             ret_val.append(definition)
-
     _logger().debug("Document structure changed %s")
-    status = True
     ret_val = [d.to_dict() for d in ret_val]
-    return status, ret_val
+    return ret_val
 
 
 def quick_doc(request_data):
@@ -188,7 +194,7 @@ def quick_doc(request_data):
         return []
     else:
         ret_val = [d.doc for d in definitions]
-        return True, ret_val
+        return ret_val
 
 
 def run_pep8(request_data):
@@ -211,12 +217,12 @@ def run_pep8(request_data):
     except Exception:
         _logger().exception('Failed to run PEP8 analysis with data=%r'
                             % request_data)
-        return False, []
+        return []
     else:
         messages = []
         for line_number, offset, code, text, doc in results:
             messages.append(('[PEP8] %s' % text, WARNING, line_number - 1))
-        return True, messages
+        return messages
 
 
 def run_frosted(request_data):
@@ -233,8 +239,12 @@ def run_frosted(request_data):
     code = request_data['code']
     path = request_data['path']
     encoding = request_data['encoding']
-    if not code or not encoding or not path:
-        status = False
+    if not encoding:
+        encoding = 'utf-8'
+    if not path:
+        path = os.path.join(tempfile.gettempdir(), 'temp.py')
+    if not code:
+        return []
     else:
         # First, compile into an AST and handle syntax errors.
         try:
@@ -263,9 +273,8 @@ def run_frosted(request_data):
                 status = (WARNING if warning.type.error_code.startswith('W')
                           else ERROR)
                 ret_val.append((msg, status, line))
-        status = True
     prev_results = ret_val
-    return status, ret_val
+    return ret_val
 
 
 def icon_from_typename(name, icon_type):
@@ -286,6 +295,7 @@ def icon_from_typename(name, icon_type):
              'KEYWORD': ':/pyqode_python_icons/rc/keyword.png',
              'PARAM': ':/pyqode_python_icons/rc/var.png',
              'ARRAY': ':/pyqode_python_icons/rc/var.png',
+             'INSTANCEELEMENT': ':/pyqode_python_icons/rc/var.png',
              'INSTANCE': ':/pyqode_python_icons/rc/var.png',
              'PARAM-PRIV': ':/pyqode_python_icons/rc/var.png',
              'PARAM-PROT': ':/pyqode_python_icons/rc/var.png',
